@@ -76,8 +76,7 @@ def delete_old_cert(client):
 
 def client_post_request (cert_path, by_host):
     if os.path.exists(cert_path + 'req_id'):
-        print _("You have already sent a request for the certificate to be "\
-                "signed.")
+        print _("You already sent a certificate signature request.")
         print _("Request ID = %s") %open(cert_path + 'req_id', 'r').read()
         ans = raw_input (_("Send a new request? y/[n]: "))
         if not ans.lower() in ['y','yes']:
@@ -244,7 +243,7 @@ def client_get_cert(cert_path, args):
             fa.close()
             print _("Certificate added")
         else:
-            print _("file with the CA certificate now exists")
+            print _("file containing the CA certificate now exists")
     return 0
     
 def client_post_auth(client):
@@ -255,9 +254,10 @@ def client_post_auth(client):
             pass#client_post_cert(client)
         else:
             #client_post_request(client)
-            print _('You do not have a certificate. Use --gen-cert-by HOST '
-                    'to generate a new certificate or --get-cert-from HOST '
-                    'to get a new certificate from the server.')
+            print _('You do not have a certificate. Use option '
+                    '--gen-cert-by HOST to generate a new certificate '
+                    'or --get-cert-from HOST to get the certificate '
+                    'from the server.')
             sys.exit()
         print client.service.versions(sid, VERSION)
     except VerifyError, e:
@@ -287,7 +287,7 @@ def client_view_cert_right(client):
     try:
         cert_id = int (cert_id)
     except:
-        print _("Certificate ID error")
+        print _("Invalid certificate ID")
         return 1
     try:
         sid = get_sid(client.SID_FILE)
