@@ -165,7 +165,7 @@ class clientHTTPSConnection (httplib.HTTPSConnection):
                 print _("filename = "), filename
                 print _("Certificate added")
             else:
-                print _("file with the CA certificate now exists")
+                print _("file containing the CA certificate now exists")
         get_CRL(cl_client_cert_dir + '/')
     
     
