@@ -217,10 +217,10 @@ class Field(DataVarsSerializer):
                            self.elementByType(self.type)
             if not onlyhelp or varObj.syntax:
                 self.label = varObj.label or varObj.name
-                #if inbrief:
-                #    self.uncompatible = ""
-                #else:
-                self.uncompatible = dv.Uncompatible(varObj.name)
+                if inbrief:
+                    self.uncompatible = ""
+                else:
+                    self.uncompatible = dv.Uncompatible(varObj.name)
                 if self.uncompatible:
                     for var in varObj.reqUncompat:
                         if not briefmode and var in groupVars:
@@ -282,18 +282,20 @@ class GroupField(DataVarsSerializer):
                     if not var in groupDepVars:
                         groupDepVars.append(var)
 
-            uniqBrief = list(set(info['brief'])- set(info['normal'])-
+            uniqBrief = list((set(info['brief']) | set(info['brief_force'])) - \
+                            set(info['normal'])-
                              set(info['expert']))
             if brief:
                 for varname in uniqBrief:
                     varObj = dv.getInfo(varname)
-                    self.fields.append(Field(dv=dv,inbrief=True,
+                    inbrief = varname in info['brief_force']
+                    self.fields.append(Field(dv=dv,inbrief=inbrief,
                                              briefmode = brief,
                                              varObj=varObj,
                                              groupVars=groupDepVars,
                                              onlyhelp=onlyhelp))
             for varname in info['normal']:
-                inbrief = brief and varname in info['brief']
+                inbrief = brief and varname in info['brief_force']
                 if brief and 'hide' in info and  varname in info['hide']:
                     continue
                 varObj = dv.getInfo(varname)
@@ -311,7 +313,7 @@ class GroupField(DataVarsSerializer):
                                  label=info['expert_label'],
                                  value="open"))
                         for varname in info['expert']:
-                            inbrief = brief and varname in info['brief']
+                            inbrief = brief and varname in info['brief_force']
                             if brief and 'hide' in info and \
                                 varname in info['hide']:
                                 continue
