@@ -706,7 +706,9 @@ def sing_req_by_server(id_client_req, cert_path, data_path, auto = False):
         if auto:
             group_name = "all"
         else:
-            group_name = "%s" %raw_input \
+            group_name = ""
+            while not group_name.split():
+                group_name = "%s" %raw_input \
                                 (_("Enter the group of the new certificate "\
                                    "(group name or 'all'): "))
         config = data_path + '/client_certs/ssl-client.cfg'
@@ -1207,9 +1209,10 @@ def parse(full=False):
     parser.add_argument(
         '--gui-warning', action='store_true', default=False, 
         dest = 'gui_warning', help=_('display warnings at the end'))
-    parser.add_argument(
-        '-f', '--force', action='store_true', default=False,
-        dest = 'no_questions', help=_('silent during the process'))
+    if full:
+        parser.add_argument(
+            '-f', '--force', action='store_true', default=False,
+            dest = 'no_questions', help=_('silent during the process'))
     parser.add_argument(
         '-P', action='store_true', default=False,
         dest = 'stdin_passwd',
