@@ -86,7 +86,7 @@ def makeRequest(pubkey, pkey, serv_host, port):
             name.ST = ''
         else:
             name.ST.replace(' ', '_').replace('\t', '_')
-        name.C = raw_input (_('Country (TWO letters only!): '))
+        name.C = raw_input (_('Country (two letters only!): '))
 
     req.set_subject_name(name)
     #ext1 = X509.new_extension('nsComment', 'Hello there')
