@@ -461,9 +461,15 @@ class CoreWsdl():
             self.addMessage(type = 'endTask', message = result)
             self.setProgress(100, progress_message)
 
-        def askConfirm(self, message):
+        def askConfirm(self, message,default="yes"):
             self.addMessage(type = 'confirm', message = message)
-            return self.getAnswer()
+            ret = self.getAnswer()
+            if ret == "":
+                return default
+            return ret
+
+        def isInteractive(self):
+            return True
 
         def askChoice(self,message,answers=[("yes","Yes"),("no","No")]):
             self.addMessage(type = 'choice',message="%s|%s"%(message,
