@@ -287,7 +287,7 @@ class replaceClass():
                 return default
             while True:
                 try:
-                    ask = raw_input(message+ '? (yes/no): ')
+                    ask = raw_input(message+ ' (yes/no): ')
                 except KeyboardInterrupt:
                     ask = 'no'
                     print
