@@ -15,7 +15,7 @@
 #  limitations under the License.
 
 
-__version__ = "3.1.4"
+__version__ = "3.1.6"
 __app__ = "calculate-core"
 
 import sys, os
@@ -168,8 +168,7 @@ class updateUserConfigs(shareUpdateConfigs):
         # X session user + configured local users (if user profile was not
         # configured then there is no need setup package for this user
         xUsers = filter(lambda x:not "(unknown)" in x,
-                 list((set(self.getXUsers()) | 
-                       set(self.getConfiguredPasswdUsers()))))
+                 list((set(self.getXUsers()))))
         if not xUsers:
             self.logger.info(_("Package %s") %nameProgram)
             self.logger.warn(_("X session users not found"))
@@ -180,6 +179,7 @@ class updateUserConfigs(shareUpdateConfigs):
         listIndex = []
         mergeProgram = "calculate-utilities"
         firstValue = True
+        printOut = False
         for userName in xUsers:
             clVars.Set("cl_root_path", '/', True)
             clVars.Set("ur_login", userName, True)
@@ -202,7 +202,8 @@ class updateUserConfigs(shareUpdateConfigs):
                                printERROR=self.printERROR,
                                askConfirm=self.askConfirm,
                                printWARNING=self.printWARNING,
-                               printWarning=False)
+                               printWarning=False,
+                               userProfile=True)
             clTempl.onFirstValue = lambda *args: \
                     self.startTask(
                         _("User configuring the {nameProgram} package by "
@@ -225,10 +226,13 @@ class updateUserConfigs(shareUpdateConfigs):
                 if not nameAndVerPkg in dictPakkages:
                     listIndex.append(nameAndVerPkg)
                     dictPakkages[nameAndVerPkg] = []
+                    if filter(lambda x:not "calculate/ini.env" in x,
+                       dirsFiles[1]):
+                        printOut = True
                 dictPakkages[nameAndVerPkg].append((userName,
                     sorted(list(set(dirsFiles[1])))))
         self.endTask()
-        if dictPakkages:
+        if printOut and dictPakkages:
             for calcPkg in listIndex:
                 self.printSUCCESS(_("Calculate Utilities have changed files")\
                                   +":")
