@@ -25,7 +25,7 @@ from calculate.core.server.api_types import (ChoiceValue, Table, Field,
                                              ReturnedMessage, Option)
 
 from calculate.lib.cl_lang import setLocalTranslate
-setLocalTranslate('cl_core',sys.modules[__name__])
+setLocalTranslate('cl_core3',sys.modules[__name__])
 
 class SH (ClassSerializer):
     name = String
@@ -137,7 +137,7 @@ class CoreWsdl:
         except KeyboardInterrupt:
             try:
                 # Необходимо передать Fasle для сохранения данных о процессе
-                self.printERROR(_('Interrupted by the user'))
+                self.printERROR(_('Manually interrupted'))
                 return False
             except KeyboardInterrupt:
                 return False
